@@ -38,7 +38,7 @@ public:
     qreal scale() const;
     QPoint globalPosition() const;
     QSize pixelSize() const;
-    int refreshRate() const;
+    float refreshRate() const;
     uint32_t vrrPolicy() const;
     uint32_t overscan() const;
     uint32_t capabilities() const;
@@ -99,7 +99,7 @@ protected:
 
 private:
     QString modeName(const WaylandOutputDeviceMode *m) const;
-    WaylandOutputDeviceMode *deviceModeFromId(const int modeId) const;
+    WaylandOutputDeviceMode *deviceModeFromId(const QString &id) const;
 
     WaylandOutputDeviceMode *m_mode;
     QList<WaylandOutputDeviceMode *> m_modes;
